CutDendroComp: Cut a dendrogram into a predefined number of groups

Description Usage Arguments Value

View source: R/CutDendroComp.R

Description

Cut a dendrogram into a predefined number of groups

Usage

1
2
CutDendroComp(dendro, n_groups = NULL, height = NULL, plot = FALSE,
  min_num = NULL, rect_opt, ...)

Arguments

dendro

an object of class hclust

n_groups

The dataset that you want to depict. It can be a single character or a numeric value refers to the element of the compare object.

plot

Logical. If FALSE you have to define the group_n argumentum and a dataframe is returned with cluster names and groups a according hierachical clustering. This dataframe can be inputed to the GoupComp function. Otherwise you can plot a dendrogram with our withour a heatmap

min_num

Integer. Minimum size of a group.

rect_opt

argument passed to the rect.hclust function as a list

...

arguments passed to the plot function

Value

this function returns a compare object retain only just part of the original clusters


vtorda/CompareTools documentation built on Nov. 6, 2019, 9:07 p.m.