Description Usage Arguments Value
View source: R/CutDendroComp.R
Cut a dendrogram into a predefined number of groups
1 2 |
dendro |
an object of class hclust |
n_groups |
The dataset that you want to depict. It can be a single character or a numeric value refers to the element of the compare object. |
plot |
Logical. If FALSE you have to define the group_n argumentum and a dataframe is returned with cluster names and groups a according hierachical clustering. This dataframe can be inputed to the GoupComp function. Otherwise you can plot a dendrogram with our withour a heatmap |
min_num |
Integer. Minimum size of a group. |
rect_opt |
argument passed to the rect.hclust function as a list |
... |
arguments passed to the plot function |
this function returns a compare object retain only just part of the original clusters
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.